#!/usr/local/bin/perl
#
# cluster definitions for MARCC/BlueCrab
# Just a dummy so we can track projects in PDB

package Glue::HPCC::Cluster::BlueCrab;
use strict;
use warnings;
use base qw(Glue::HPCC::Cluster);
use Carp qw(carp croak);


#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

my $CLUSTERNAME="bluecrab";
my $CLUSTERSHORT="bc";
my $NETGROUP = '';
my $HOMEROOT_USER = "Nonsense-data";
my $HOMEROOT_ADMIN = "Nonsense-data2";
my $SCHEDTYPE = 'dummy';
my $HEADNODE="${CLUSTERNAME}.marcc.jhu.edu";
my $DOMAIN="${CLUSTERNAME}.umd.edu";
my $DB_CLUSTERNAME=$CLUSTERSHORT;
my $UNIXGRP_PREFIX = "bc-";
my $HOME_SOFTQUOTA_LOGFILE='Nonsense-data3';

my $DBNAME="hpcc";
my $DBHOST = "bighorn.umd.edu";


#-------------------------------------------------------------------
#	Database stuff
#-------------------------------------------------------------------

sub db_connection_string($)
{	my $obj = shift;
	my $connstr = "dbi:Pg:dbname=${DBNAME};host=${DBHOST}";
	return $connstr;
}

#-------------------------------------------------------------------
#	Overloaded methods
#-------------------------------------------------------------------

sub headnode($)
{	my $class = shift;
	return $HEADNODE;
}

sub domain($)
{	my $class = shift;
	return $DOMAIN;
}

sub clustername($)
{	my $class = shift;
	return $CLUSTERNAME;
}

sub clustershort($)
{	my $class = shift;
	return $CLUSTERSHORT;
}

sub db_clustername($)
{	my $class = shift;
	return $DB_CLUSTERNAME;
}

sub clusters_sharing_pdb_tables($)
#We share some PDB tables with Deepthoughts as well as Pippin
{       my $class = shift;
        return [ 'deepthought', 'deepthought2', 'bluecrab', 'pippin' ];
}

sub netgroup($)
{	my $class = shift;
	return $NETGROUP;
}

sub homeroot_user($)
{	my $class = shift;
	return $HOMEROOT_USER;
}

sub homeroot_admin($)
{	my $class = shift;
	return $HOMEROOT_ADMIN;
}

sub home_softquota_logfile($)
{	my $class = shift;
	return $HOME_SOFTQUOTA_LOGFILE;
}

sub scheduler_type($)
{	my $class = shift;
	return $SCHEDTYPE;
}

sub unixgrp_prefix($)
{	my $class = shift;
	return $UNIXGRP_PREFIX;
}

sub lustre_filesystems($)
#Returns a list ref of lustre filesystems 
{	my $class = shift;
	return [  ];
}

sub nfs_data_filesystems($)
#Returns a list ref of NFS data filesystems 
{	my $class = shift;
	return [ 
		 ];
}

sub mailinglist_name($)
{	my $class = shift;
	return '';
}

sub mailinglist_pwdfile($)
{	my $class = shift;
	return '';

}

sub should_users_get_db_access($)
{	my $class = shift;
	return 0;
}

sub running_in_cluster($)
{	return 1;
}

sub running_on_headnode($)
{	return 1;
}

1;
__END__

=head1 NAME

Glue::HPCC::Cluster::BlueCrab - Settings for MARCC/BlueCrab

=head1 SYNOPSIS

  use Glue::HPCC::Cluster;
  my $dt2 = Glue::HPCC::Cluster->new_from_clustername('dt');

  ...


=head1 DESCRIPTION

This is the Glue::HPCC::Cluster instance with settings for MARCC/BlueCrab
cluster.  See Glue::HPCC::Cluster for more info.

Only exists so we can track allocations in PDB.





