#!/usr/local/bin/perl
#
#Bswift 1 cluster definitions

package Glue::HPCC::Cluster::Bswift;
use strict;
use warnings;
use base qw(Glue::HPCC::Cluster);
use Carp qw(carp croak);


#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

my $CLUSTERNAME="bswift";
my $CLUSTERSHORT="bswift";
my $NETGROUP = "HPCC-bswift";
my $HOMEROOT_USER = "/home/bswift";
my $HOMEROOT_ADMIN = "/home/bswift";

my $SCHEDTYPE = 'slurm';
my $SCHEDVERSION = '16.05.1';

my $HEADNODE="${CLUSTERNAME}.umd.edu";
my $DOMAIN="${CLUSTERNAME}.umd.edu";
my $DB_CLUSTERNAME=$CLUSTERSHORT;
my $UNIXGRP_PREFIX = "bswift-";

my $DBNAME="hpcc_bswift";
my $DBHOST = "bighorn.umd.edu";


#-------------------------------------------------------------------
#	Database stuff
#-------------------------------------------------------------------

sub db_connection_string($)
{	my $obj = shift;
	my $connstr = "dbi:Pg:dbname=${DBNAME};host=${DBHOST}";
	return $connstr;
}

#-------------------------------------------------------------------
#	Overloaded methods
#-------------------------------------------------------------------

sub headnode($)
{	my $class = shift;
	return $HEADNODE;
}

sub domain($)
{	my $class = shift;
	return $DOMAIN;
}

sub clustername($)
{	my $class = shift;
	return $CLUSTERNAME;
}

sub clustershort($)
{	my $class = shift;
	return $CLUSTERSHORT;
}

sub db_clustername($)
{	my $class = shift;
	return $DB_CLUSTERNAME;
}

sub netgroup($)
{	my $class = shift;
	return $NETGROUP;
}

sub homeroot_user($)
{	my $class = shift;
	return $HOMEROOT_USER;
}

sub homeroot_admin($)
{	my $class = shift;
	return $HOMEROOT_ADMIN;
}

sub scheduler_type($)
{	my $class = shift;
	return $SCHEDTYPE;
}

sub unixgrp_prefix($)
{	my $class = shift;
	return $UNIXGRP_PREFIX;
}

sub lustre_filesystems($)
#Returns a list ref of lustre filesystems 
{	my $class = shift;
	return [ ];
}

sub nfs_data_filesystems($)
#Returns a list ref of NFS data filesystems 
{	my $class = shift;
	return [ 'data/bswift-1',
		 ];
}

sub mailinglist_name($)
#No mailing list for bswift at this time
{	my $class = shift;
	return;
}

sub should_users_get_db_access($)
{       my $class = shift;
        return 0;
}

sub scheduler_version($)
{	return $SCHEDVERSION if $SCHEDVERSION;
	return '14';
}

sub scheduler_rootdir($)
{	#return $SCHEDROOTDIR if ( $SCHEDROOTDIR);
	if ( $SCHEDVERSION )
	{	return "/usr/local/slurm/$SCHEDVERSION";
	} else 
	{	return '/usr/local/slurm';
	}
}

1;
__END__

=head1 NAME

Glue::HPCC::Cluster::Bswift - Settings for Bswift

=head1 SYNOPSIS

  use Glue::HPCC::Cluster;
  my $dt2 = Glue::HPCC::Cluster->new_from_clustername('dt');

  ...


=head1 DESCRIPTION

This is the Glue::HPCC::Cluster instance with settings for Bswift
cluster.  See Glue::HPCC::Cluster for more info.





