#!/usr/local/bin/perl
#
#Deepthought 1 cluster definitions

package Glue::HPCC::Cluster::Deepthought;
use strict;
use warnings;
use base qw(Glue::HPCC::Cluster);
use Carp qw(carp croak);


#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

my $CLUSTERNAME="deepthought";
my $CLUSTERSHORT="dt";
my $NETGROUP = "HPCC-deepthought";
my $HOMEROOT_USER = "/export/lustre_1/home";
my $HOMEROOT_ADMIN = "/export/lustre_1/home";

my $SCHEDTYPE = 'slurm';
my $SCHEDVERSION = '16.05.1';

my $HEADNODE="${CLUSTERNAME}.umd.edu";
my $DOMAIN="${CLUSTERNAME}.umd.edu";
my $DB_CLUSTERNAME=$CLUSTERSHORT;
my $UNIXGRP_PREFIX = "dt-";
my $HOME_SOFTQUOTA_LOGFILE='/software/glue-cluster/quotas/homespace-status.dat';

my $DBNAME="hpcc";
my $DBHOST = "bighorn.umd.edu";


#-------------------------------------------------------------------
#	Database stuff
#-------------------------------------------------------------------

sub db_connection_string($)
{	my $obj = shift;
	my $connstr = "dbi:Pg:dbname=${DBNAME};host=${DBHOST}";
	return $connstr;
}

#-------------------------------------------------------------------
#	Overloaded methods
#-------------------------------------------------------------------

sub headnode($)
{	my $class = shift;
	return $HEADNODE;
}

sub domain($)
{	my $class = shift;
	return $DOMAIN;
}

sub clustername($)
{	my $class = shift;
	return $CLUSTERNAME;
}

sub clustershort($)
{	my $class = shift;
	return $CLUSTERSHORT;
}

sub db_clustername($)
{	my $class = shift;
	return $DB_CLUSTERNAME;
}

sub netgroup($)
{	my $class = shift;
	return $NETGROUP;
}

sub homeroot_user($)
{	my $class = shift;
	return $HOMEROOT_USER;
}

sub homeroot_admin($)
{	my $class = shift;
	return $HOMEROOT_ADMIN;
}

sub home_softquota_logfile($)
{	my $class = shift;
	return $HOME_SOFTQUOTA_LOGFILE;
}

sub scheduler_type($)
{	my $class = shift;
	return $SCHEDTYPE;
}

sub unixgrp_prefix($)
{	my $class = shift;
	return $UNIXGRP_PREFIX;
}

sub lustre_filesystems($)
#Returns a list ref of lustre filesystems 
{	my $class = shift;
	return [ '/export/lustre_1' ];
}

sub nfs_data_filesystems($)
#Returns a list ref of NFS data filesystems 
{	my $class = shift;
	return [ 
		'/data/dt-vol0',
		'/data/dt-vol1',
		'/data/dt-vol6',
		 ];
}

sub mailinglist_name($)
{	my $class = shift;
	return 'HPCC-ANNOUNCE';
}

sub mailinglist_pwdfile($)
{	my $class = shift;
	return '/software/glue-cluster/priv/hpcc-announce.pwd';
}

sub clusters_sharing_mailinglist($)
#We share a mailing list with Deepthought2
{	my $class = shift;
	return [ 'deepthought2' ];
}

sub clusters_sharing_pdb_tables($)
#We share some PDB tables with Deepthought2, as well as Bluecrab, Pippin
{       my $class = shift;
	return [ 'deepthought2', 'bluecrab', 'pippin' ];
}

sub clusters_sharing_unixgrp_prefix($)
#We share dt- with Deepthought2
{	my $class = shift;
	return [ 'deepthought', 'deepthought2' ];
}


sub should_users_get_db_access($)
{	my $class = shift;
	return 0;
}

sub scheduler_version($)
{	return $SCHEDVERSION if $SCHEDVERSION;
	return '14';
}

sub scheduler_rootdir($)
{	#return $SCHEDROOTDIR if ( $SCHEDROOTDIR);
	if ( $SCHEDVERSION )
	{	return "/usr/local/slurm/$SCHEDVERSION";
	} else 
	{	return '/usr/local/slurm';
	}
}

1;
__END__

=head1 NAME

Glue::HPCC::Cluster::Deepthought - Settings for Deepthought

=head1 SYNOPSIS

  use Glue::HPCC::Cluster;
  my $dt2 = Glue::HPCC::Cluster->new_from_clustername('dt');

  ...


=head1 DESCRIPTION

This is the Glue::HPCC::Cluster instance with settings for Deepthought
cluster.  See Glue::HPCC::Cluster for more info.





