#!/usr/local/bin/perl
#
#Deepthought 2 cluster definitions

package Glue::HPCC::Cluster::Deepthought2;
use strict;
use warnings;
use base qw(Glue::HPCC::Cluster);
use Carp qw(carp croak);

#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

my $CLUSTERNAME="deepthought2";
my $CLUSTERSHORT="dt2";
my $DB_CLUSTERNAME=$CLUSTERSHORT;
my $NETGROUP = "HPCC-deepthought2";
my $HOMEROOT_USER = "/home/deepthought2";
my $HOMEROOT_ADMIN = "/home/dt2-admin";

my $SCHEDTYPE = 'slurm';
my $SCHEDVERSION = '16.05.1';


my $HEADNODE="${CLUSTERNAME}.umd.edu";
my $DOMAIN="${CLUSTERNAME}.umd.edu";
my $UNIXGRP_PREFIX = 'dt-';
my $HOME_SOFTQUOTA_LOGFILE='/software/glue-cluster/quotas/homespace-status.dat';

my $DBNAME="hpcc";
my $DBHOST = "bighorn.umd.edu";

#-------------------------------------------------------------------
#	Database stuff
#-------------------------------------------------------------------

sub db_connection_string($)
{	my $obj = shift;
	my $connstr = "dbi:Pg:dbname=${DBNAME};host=${DBHOST}";
	return $connstr;
}

#-------------------------------------------------------------------
#	Overloaded methods
#-------------------------------------------------------------------

sub headnode($)
{	my $class = shift;
	return 'deepthought2.umd.edu';
}

sub domain($)
{	my $class = shift;
	return 'deepthought2.umd.edu';
}

sub clustername($)
{	my $class = shift;
	return $CLUSTERNAME;
}

sub clustershort($)
{	my $class = shift;
	return $CLUSTERSHORT;
}

sub db_clustername($)
{	my $class = shift;
	return $DB_CLUSTERNAME;
}

sub netgroup($)
{	my $class = shift;
	return $NETGROUP;
}

sub homeroot_user($)
{	my $class = shift;
	return $HOMEROOT_USER;
}

sub homeroot_admin($)
{	my $class = shift;
	return $HOMEROOT_ADMIN;
}

sub home_softquota_logfile($)
{       my $class = shift;
        return $HOME_SOFTQUOTA_LOGFILE;
}

sub scheduler_type($)
{	my $class = shift;
	return $SCHEDTYPE;
}

sub unixgrp_prefix($)
{	my $class = shift;
	return $UNIXGRP_PREFIX;
}

sub lustre_filesystems($)
#Returns a list ref of lustre filesystems 
{       my $class = shift;
        return [ '/lustre' ];
}

sub nfs_data_filesystems($)
#Returns a list ref of lustre filesystems 
{       my $class = shift;
        return [ ];
}

sub mailinglist_name($)
{	my $class = shift;
	return 'HPCC-ANNOUNCE';
}

sub mailinglist_pwdfile($)
{	my $class = shift;
	return '/software/glue-cluster/priv/hpcc-announce.pwd';
}


sub clusters_sharing_mailinglist($)
#We share a mailing list with original Deepthought cluster
{	my $class = shift;
	return [ 'deepthought' ];
}

sub clusters_sharing_pdb_tables($)
#We share some PDB tables with Deepthought as well as Bluecrab and Pippin
{       my $class = shift;
        return [ 'deepthought', 'bluecrab', 'pippin' ];
}

sub clusters_sharing_unixgrp_prefix($)
#We share dt- with Deepthought
{       my $class = shift;
        return [ 'deepthought', 'deepthought2' ];
}

sub should_users_get_db_access($)
{	my $class = shift;
	return 0;
}

sub scheduler_version($)
{	return $SCHEDVERSION if $SCHEDVERSION;
	return '14';
}

sub scheduler_rootdir($)
{	#return $SCHEDROOTDIR if ( $SCHEDROOTDIR);
	if ( $SCHEDVERSION )
	{	return "/usr/local/slurm/$SCHEDVERSION";
	} else 
	{	return '/usr/local/slurm';
	}
}

1;
__END__

=head1 NAME

Glue::HPCC::Cluster::Deepthought2 - Settings for Deepthought2

=head1 SYNOPSIS

  use Glue::HPCC::Cluster;
  my $dt2 = Glue::HPCC::Cluster->new_from_clustername('dt2');

  ...


=head1 DESCRIPTION

This is the Glue::HPCC::Cluster instance with settings for Deepthought2
cluster.  See Glue::HPCC::Cluster for more info.





