#!/usr/local/bin/perl
#
#Does the heavy lifting for Cluster management
#project creation, user management, etc.
#For Dummy clusters (e.g. no management of actual cluster, just track 
#allocations in PDB).

package Glue::HPCC::ClusterUtil::Dummy::User;
use strict;
use warnings;
use base qw(Glue::HPCC::ClusterUtil::User);
use Carp qw(carp croak);
use DBI;
use POSIX qw(floor);

use Glue::HPCC::Cluster;

use Glue::HPCC::Project::Log;
use Glue::HPCC::Project::ProjectType;


#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

my $DEBUG;
$DEBUG=1;

my $DRYRUN;
my $VERBOSE;

#-------------------------------------------------------------------
#	Common Methods: verbosity and dryrun mode
#-------------------------------------------------------------------

sub verbose($;$)
#Sets verbosity on all of our subordinate modules
{	my $class = shift;
	my $val = shift;

        if ( defined $val )
        {       $val = $val?1:0;
                $VERBOSE=$val;
        }
        return $VERBOSE;
}

sub dryrun($$)
#Sets verbosity on all of our subordinate modules
{	my $class = shift;
	my $val = shift;

        if ( defined $val )
        {       $val = $val?1:0;
                $DRYRUN=$val;
        }
        return $DRYRUN;
}

#-------------------------------------------------------------------
#	Get/set default account for user
#-------------------------------------------------------------------

sub get_default_account_for_user($@)
#Returns the default account associated with user account.
#Takes key=>value pairs:
#	hpc: Glue::HPCC::Cluster instance, REQUIRED
#	user: username, REQUIRED
#
#Returns true (account name) on success.
#Otherwise, either croaks or returns false
{	my $class = shift;
	my %args = @_;

	return;
}

sub set_default_account_for_user($@)
#Sets the default account associated with user
#Takes key => value pairs
#	hpc: Glue::HPCC::Cluster instance, REQUIRED
#	user: username, REQUIRED
#	account: account name, REQUIRED
#	reason: for logging, REQUIRED
#
#Returns false on success.
#Otherwise, either croaks or returns true (error message)
{	my $class = shift;
	my %args = @_;
	my $me = 'set_default_account_for_user';

	return;
}

sub sched_add_user_to_hpc_cluster($@)
#Adds specified user from the specified HPC cluster.
#
#Takes key=>value pairs, recognizing:
#       hpc => Glue::HPCC::Cluster instance, REQUIRED
#       user => username of user to remove from cluster. REQUIRED
#       reason => reason user being removed, REQUIRED
#	FIXME => operate in FIXME mode.
{	my $class = shift;
	my %args = @_;
	my $me = 'sched_add_user_to_hpc_cluster';

	return;
}

sub sched_remove_user_from_hpc_cluster($@)
#Removes specified user from the specified HPC cluster.
#
#Takes key=>value pairs, recognizing:
#       hpc => Glue::HPCC::Cluster instance, REQUIRED
#       user => username of user to remove from cluster. REQUIRED
#       reason => reason user being removed, REQUIRED
{	my $class = shift;
	my %args = @_;
	my $me = 'sched_remove_user_from_hpc_cluster';

	return;
}

#-------------------------------------------------------------------
#	Add/remove user from project (scheduler tasks)
#-------------------------------------------------------------------

sub sched_add_user_to_project_in_cluster($@)
#Does the slurm scheduler specific tasks for adding 
#specified user to specified project in specified cluster.
#
#Takes  key => value pairs,
#	hpc => Glue::HPCC::Cluster instance, REQUIRED
#	user => username to add, REQUIRED
#	project => project to add to, REQUIRED
#	projtype => project type (name), REQUIRED e.g. coop, condo
#	reason => reason for logs, REQUIRED
#	highpriority => should user get access to condo's hi-prio QoS
#		Only valid on projects of type 'condo'
#	defaultaccount => if given, sets user default account to this
#	FIXME: if true, operate in repair mode.
#Cluster is specified via $hpc
#
#This handles the scheduler side of things, and is usually called from
#add_user_to_project_in_cluster from scheduler independent base class.
#
#Returns false on success.  On error, either croaks or returns true (error
#message)
{	my $class = shift;
	my %args = @_;
	my $me = 'sched_add_user_to_project_in_cluster';

	return;
}

sub sched_del_user_from_project_in_cluster($@)
#Does the slurm scheduler specific tasks for adding 
#specified user to specified project in specified cluster.
#
#Takes  key => value pairs,
#	hpc => Glue::HPCC::Cluster instance, REQUIRED
#	user => username to delete, REQUIRED
#	project => project to delete from, REQUIRED
#	projtype => project type (name), REQUIRED e.g. coop, condo
#	reason => reason for logs, REQUIRED
#	adjust_balances => adjust proj/account balances after delete.  See below
#Cluster is specified via $hpc
#
#This handles the scheduler side of things, and is usually called from
#delete_user_from_project_in_cluster from scheduler independent base class.
#
#adjust_balances: When user deleted from Dummy account, his usage against that account
#is also deleted, and account's balance goes up.  If adjust_balances is set, the user's
#usage against the project's accounts will be deducted after deletion.
#Returns false on success.  On error, either croaks or returns true (error
#message)
{	my $class = shift;
	my %args = @_;
	my $me = 'sched_del_user_from_project_in_cluster';

	return;
}

#-------------------------------------------------------------------
#	Generic list users
#-------------------------------------------------------------------

sub sched_list_users($@)
#Returns list ref of names of users known to scheduler.  Possibly
#restricted to a cluster and/or account(s).
#Takes key=>value pairs
#
#Just a wrapper for sacctmgr_list_users
#	cluster => cluster name
#	account => either scalar string of account name
{	my $class = shift;
	my %args = @_;
	my $me = 'sched_list_users';

	return [];
}


sub add_user_to_cluster_netgroup($@)
{	return;
}

sub make_user_directories($@)
{	return;
}

1;
__END__

=head1 NAME

Glue::HPCC::ClusterUtil::Dummy::User - User management under Dummy

=head1 SYNOPSIS

  ...

