#!/usr/local/bin/perl
#
#Some common definitions for Glue::HPCC::ClusterUtil::Slurm::[Project,User]

package Glue::HPCC::ClusterUtil::Slurm::Common;
use strict;
use warnings;
use Carp qw(carp croak);
#use Glue::HPCC::ClusterUtil::Slurm::Project;

#-------------------------------------------------------------------
#	QoS definitions
#-------------------------------------------------------------------


#Standard QoSes allow to normal priority co-op, lease, and AAC grant types
#as well as high priority co-op and lease-hi types
my @QOSES_STANDARD =
(       'narrow-long',
        'narrow-med',
        'wide-med',
        'wide-short',
);

#Extended run-time QoSes, only available to hipri coop and lease-hi types
my @QOSES_EXTENDED =
(       'med-extended',
        'narrow-extended',
);

#QoS for debug and scavenger queues
my $QOS_DEBUG='debug';
my $QOS_SCAVENGER='scavenger';

sub qoses_standard($)
{	my $class = shift;
	return [ @QOSES_STANDARD ];
}

sub qoses_extended($)
{	my $class = shift;
	return [ @QOSES_EXTENDED ];
}

sub qos_debug($)
{	my $class = shift;
	return $QOS_DEBUG;
}

sub qos_scavenger($)
{	my $class = shift;
	return $QOS_SCAVENGER;
}

#--------------------------------------------------------------------------
#		Misc utilities 
#--------------------------------------------------------------------------

sub _require_cluster_exists_in_sacctmgr($$$)
{	my $class = shift;
	my $me = shift;
	my $cluster = shift;

	my $cluster_hash = Glue::HPCC::ClusterUtil::Slurm::Project->get_sacctmgr_cluster_hash;
	return if ( exists $cluster_hash->{lc $cluster} );

	my @tmp = sort ( keys %$cluster_hash);
	my $tmp = join ", ", @tmp;
	croak "$me: Invalid cluster '$cluster'; expecting one of [ $tmp ]";
}
	
1;
__END__

=head1 NAME

Glue::HPCC::ClusterUtil::Slurm::Common - Common defs for Slurm cluster utils

=head1 SYNOPSIS

  use Glue::HPCC::ClusterUtil::Slurm::Common;

  my @qoses = Glue::HPCC::ClusterUtil::Slurm::Common->qoses_standard;

  ...


=head1 DESCRIPTION

This provides some common defintions for use by the Slurm cluster util classes,
namely B<Glue::HPCC::ClusterUtil::Slurm::User> and 
B<Glue::HPCC::ClusterUtil::Slurm::Project>.

OO interface, but only for preventing namespace pollution.  All methods are
class methods.

Significant methods are:

=over 4

=item B<qoses_standard>: Returns a list ref of the standard QoS names

=item B<qoses_extended>: Returns a list ref of the extended QoS names

=item B<qos_debug>: Returns the name for the debug QoS

=item B<qos_scavenger>: Returns the name for the scavenger QoS

=item B<_require_cluster_exists_in_sacctmgr>: Helper, croaks if specified cluster name does not exist in sacctmgr.

=back

