#!/usr/local/bin/perl
#
#AFS utilities

package Glue::HPCC::Utils::AfsUtils;
use strict;
use warnings;

use Carp qw(carp croak);
require Exporter;
our @ISA = qw(Exporter);
our @EXPORT_OK = qw( 
	afs_sysname
);

#use Glue::HPCC::Utils::ShellUtils (run_backticked_command_always);

my $FS = '/usr/afsws/bin/fs';


sub afs_sysname()
#Returns AFS sysname
{	my $cmd = "$FS getsysname";
	my $res = run_backticked_command_always($cmd);
	die "Unable to obtain sysname from fs sysname cmd: returned '$res' at "
		unless ( $res =~ /^Current sysname is '.*'$/ );
	$res =~ s/^Current sysname is '//;
	$res =~ s/'.*$//;
	return $res;
}


1;
__END__

=head1 NAME

Glue::HPCC::Utils::AfsUtils: Utils for dealing with AFS

=head1 SYNOPSIS

  use Glue::HPCC::Utils::AfsUtils qw(afs_sysname)

  my $sysname = afs_sysname;
  ...


=head1 DESCRIPTION

Assorted utilities for dealing with AFS.

=over 4

=item B<afs_sysname>

Returns the AFS sysname for this system.

=back






