#!/usr/local/bin/perl
#
#Part of Slurm::Scontrol: Perl wrapper for Slurm's scontrol cmd
#Represents a Node

package Slurm::Scontrol::Node;
use strict;
use warnings;
use base qw(Slurm::Scontrol::EntityBase);
use Carp qw(carp croak);
use POSIX qw(floor);

#-------------------------------------------------------------------
#	Globals
#-------------------------------------------------------------------

#-------------------------------------------------------------------
#	Accessors
#-------------------------------------------------------------------

my @rw_accessors = qw(
	NodeName
	Arch
	CoresPerSocket
	CPUAlloc
	CPUErr
	CPUTot
	CPULoad
	NodeAddr
	NodeHostName
	Version
	OS
	RealMemory
	AllocMem
	Sockets
	Boards
	State
	ThreadsPerCore
	TmpDisk
	Weight
	BootTime
	SlurmdStartTime
	CurrentWatts
	LowestJoules
	ConsumedJoules
	Reason
);

__PACKAGE__->mk_accessors(@rw_accessors);

#Special accessors
sub _null_list_accessor($$;$)
{	my $obj = shift;
	my $field = shift;
	my $new = shift;

	if ( defined $new )
	{	$new = undef if $new eq '(null)';
		$obj->set($field, $new);
	}
	return $obj->get($field);
}

sub _ext_sensor_accessor($$;$)
{	my $obj = shift;
	my $field = shift;
	my $new = shift;

	if ( defined $new )
	{	$new = undef if $new eq 'n/s';
		$obj->set($field, $new);
	}
	return $obj->get($field);
}

my @_null_list_accessors = qw(
	Features
	Gres
);
my ($_fld);
foreach $_fld (@_null_list_accessors)
{	no strict 'refs';
	*{$_fld} = sub { shift->_null_list_accessor($_fld, @_); };
	use strict 'refs';
}

my @_ext_sensor_accessors = qw(
	ExtSensorsJoules
	ExtSensorsWatts
	ExtSensorsTemp
);

foreach $_fld (@_ext_sensor_accessors)
{	no strict 'refs';
	*{$_fld} = sub { shift->_ext_sensor_accessor($_fld, @_); };
	use strict 'refs';
}

my @special_accessors = ( @_null_list_accessors, @_ext_sensor_accessors);


#-------------------------------------------------------------------
#	Overloaded methods
#-------------------------------------------------------------------

sub _rw_fields($)
{	my $class = shift;
	return [ @rw_accessors, @special_accessors ];
}

sub _sacctmgr_name_field($)
{	my $class = shift;
	return 'account';
}
 
sub _sacctmgr_fields_in_order($)
{	my $class = shift;
	return [ @rw_accessors ];
}

#-------------------------------------------------------------------
#	Constructors, etc
#-------------------------------------------------------------------

#All inherited

#-------------------------------------------------------------------
#	Special class methods
#-------------------------------------------------------------------

1;
__END__

=head1 NAME

Slurm::Scontrol::Node

=head1 SYNOPSIS

  use Slurm::Scontrol::Node;
  use Slurm::Scontrol;

  my $scontrol = new Slurm::Scontrol;
  my $nodes = $scontrol->show_node;

  foreach my $node (@$nodes)
  {	print $node->NodeName, " has ", $node->CPUTot, " cores\n";
  }

  ...


=head1 DESCRIPTION

Represents a Node entity in Slurm::Scontrol


