/*
	A single table with most of the information
	But restricted so most people can only see information for
	projects they belong to
*/
CREATE VIEW person_project_view
(	
	/* From hpcc_shared.project_type table */
	projtype_num, 	-- hspt.pkey
	projtype,    	-- hspt.name
	projtype_desc,	-- hspt.description
	
	/* From hpcc_shared.person table */
	ppl_pkey,	-- hsp.ppl_pkey
	username,	-- hsp.username
	fullname,	-- hsp.fullname
	email,		-- hsp.email
	min_hrs_btwn_alerts, -- hsp.min_hrs_btwn_alerts

	/* From project table */
	prj_pkey, 	-- p.prj_pkey
	proj_name, 	-- p.name
	proj_desc, 	-- p.description
	unixgroup,	-- p.unixgroup,
	su,		-- p.su,
	expiration,	-- p.expiration,
	thrhld_pct_over, -- p.thrhld_pct_over,
	thrhld_pct_under, -- p.thrhld_pct_under,

	/* From person_project_m2m table */
	is_member,	-- ppm2m.is_member
	is_poc,		-- ppm2m.is_poc
	is_coord	-- ppm2m.is_coordinator
)
AS
	SELECT
		/* From hpcc_shared.project_type table */
		hspt.pkey,
		hspt.name,
		hspt.description,
		
		/* From hpcc_shared.person table */
		hsp.ppl_pkey,
		hsp.username,
		hsp.fullname,
		hsp.email,
		hsp.min_hrs_btwn_alerts,

		/* From project table */
		p.prj_pkey,
		p.name,
		p.description,
		p.unixgroup,
		p.su,
		p.expiration,
		p.thrhld_pct_over,
		p.thrhld_pct_under,

		/* From person_project_m2m table */
		ppm2m.is_member,
		ppm2m.is_poc,
		ppm2m.is_coordinator
	FROM
		hpcc_shared.project_type as hspt,
		hpcc_shared.person as hsp,
		project as p,
		person_project_m2m as ppm2m
	WHERE
		/* Join conditions */
		hspt.pkey = p.projtype AND
		hsp.ppl_pkey = ppm2m.ppl_pkey AND
		p.prj_pkey = ppm2m.prj_pkey AND

		/* Security conditions */
		(	/* Can always see row if about me */
			hsp.username = current_user OR
			/* Can always see row if hpcc_admin or hpcc_mgr */
			pg_has_role('hpcc_admin', 'MEMBER') OR
			pg_has_role('hpcc_mgr', 'MEMBER') OR
			/* can see row if about project we are poc/coord for */
			ppm2m.prj_pkey IN
			(	SELECT prj_pkey
				FROM person_project_m2m as ppm, 
				     hpcc_shared.person as psn 
				WHERE ppm.ppl_pkey = psn.ppl_pkey
					AND psn.username = current_user
					AND ( ppm.is_poc OR
					      ppm.is_coordinator )
			)
		);


